#!perl
use 5.12.0;
use strict;
use warnings FATAL => 'all';
use Test::More;
plan skip_all => 'these tests are for authors only!' unless ( $ENV{AUTHOR_TESTING} ||  $ENV{RELEASE_TESTING} );

eval 'use Test::Signature';
plan skip_all => 'Test::Signature required for this test' if $@;

plan tests => 1;

signature_ok( );
